## ----------------------------------------------------------------------------
## Griliches and Wallace (1965) -> Grunfeld (1958)
##
## data
## availability: none
## firms: Chrysler, Goodyear, Atlantic Refining, Westinghouse, Union Oil, General Motors
## note: "Only six of the original eleven firms are used in this study, because we did not
##        succeed in reproducing and extending the original set of data for the others." (p. 313, fn. 8)
##
## analysis
## result: GM cannot be reproduced. (see also Grunfeld, 1958)
##         Small deviations for aggregate, possibly due to problems with GM.
##         G&W construct alternative model based on further variables and
##         evaluate models in 1955-1960 post-sample period
## ----------------------------------------------------------------------------

## preliminaries
source("start.R")

## data pre-processing
gr <- subset(Grunfeld, firm %in% c("Chrysler", "Goodyear", "Atlantic Refining",
  "Westinghouse", "Union Oil", "General Motors"))
gr$firm <- factor(gr$firm)
pgr <- plm.data(gr, c("firm", "year"))

## Grunfeld model (Table 1, p. 314)
## p. 313: "Table 1 reproduces Grunfeld's original estimates"
sf <- systemfit(invest ~ value + capital, method = "OLS", data = pgr)
gsummary(sf, sigma2 = FALSE)

## alternatively:
lm_CH <- lm(invest ~ capital + value, data = gr, subset = firm == "Chrysler")
lm_GY <- lm(invest ~ capital + value, data = gr, subset = firm == "Goodyear")
lm_AR <- lm(invest ~ capital + value, data = gr, subset = firm == "Atlantic Refining")
lm_WH <- lm(invest ~ capital + value, data = gr, subset = firm == "Westinghouse")
lm_UO <- lm(invest ~ capital + value, data = gr, subset = firm == "Union Oil")
lm_GM <- lm(invest ~ capital + value, data = gr, subset = firm == "General Motors")

## aggregate regression
gr_macro <- aggregate(gr[,-4], list(gr$year), sum)[,-1]
lm_macro <- lm(invest ~ capital + value, data = gr_macro)
gsummary(lm_macro, sigma2 = FALSE)
