## ----------------------------------------------------------------------------
## Grunfeld and Griliches (1960) -> Grunfeld (1958)
##
## data
## availability: none
## firms: General Motors, General Electric, US Steel, Atlantic Refining,
##        Union Oil, Diamond Match, Goodyear, American Steel
##
## analysis
## result: R^2 for General Motors cannot be reproduced
## ----------------------------------------------------------------------------

## preliminaries
source("start.R")

## data pre-processing
gr <- subset(Grunfeld, firm %in% c("General Motors", "General Electric", "US Steel",
  "Atlantic Refining", "Union Oil", "Diamond Match", "Goodyear", "American Steel"))
gr$firm <- factor(gr$firm)
pgr <- plm.data(gr, c("firm", "year"))

## R^2 of individual OLS regressions (Table 1, p. 2, cited from Grunfeld, 1958)
sf <- systemfit(invest ~ value + capital, method = "OLS", data = pgr)
gsummary(sf)

## alternatively:
lm_GM <- lm(invest ~ value + capital, data = gr, subset = firm == "General Motors")
lm_GE <- lm(invest ~ value + capital, data = gr, subset = firm == "General Electric")
lm_US <- lm(invest ~ value + capital, data = gr, subset = firm == "US Steel")
lm_AR <- lm(invest ~ value + capital, data = gr, subset = firm == "Atlantic Refining")
lm_UO <- lm(invest ~ value + capital, data = gr, subset = firm == "Union Oil")
lm_DM <- lm(invest ~ value + capital, data = gr, subset = firm == "Diamond Match")
lm_GY <- lm(invest ~ value + capital, data = gr, subset = firm == "Goodyear")
lm_AS <- lm(invest ~ value + capital, data = gr, subset = firm == "American Steel")

## aggregate regression
gr_macro <- aggregate(gr[,-4], list(gr$year), sum)[,-1]
lm_macro <- lm(invest ~ capital + value, data = gr_macro)
summary(lm_macro)$r.squared
