## ----------------------------------------------------------------------------
## Kmenta+Gilbert (1968) -> Zellner (1962)
##
## data
## availability: none
## firms: General Electric, Westinghouse
## errors: none
##
## analysis
## result: exact at precision given
## note: for all estimates pertaining to WH, value and capital are interchanged
## ----------------------------------------------------------------------------

## preliminaries
source("start.R")

## data pre-processing
gr <- subset(Grunfeld, firm %in% c("General Electric", "Westinghouse"))
gr$firm <- factor(gr$firm)
pgr <- plm.data(gr, c("firm", "year"))

## OLS, SUR and iterated SUR (ML) (pp. 1199-1200) 
fmGE <- lm(invest ~ value + capital, data = gr, subset = firm == "General Electric")
fmWH <- lm(invest ~ value + capital, data = gr, subset = firm == "Westinghouse")
gsummary(fmGE, digits = 4)
gsummary(fmWH, digits = 4)
## alternatively:
## systemfit(invest ~ value + capital, method = "OLS", data = pgr)

fmSUR <- systemfit(invest ~ value + capital, method = "SUR", data = pgr)
gsummary(fmSUR, digits = 4)

fmML <- systemfit(invest ~ value + capital, method = "SUR", data = pgr, maxit = 100)
gsummary(fmML, digits = 4)
