## Selected textbooks with online versions of the Grunfeld data
##
## - Greene   (1993)
##   source:  http://pages.stern.nyu.edu/~wgreene/Text/tables/Datasets.htm
##   firms:   see below
##   errors:  see below
##   remarks: physically identical to Greene (2003)
## - Greene (1998)
##   source:  http://pages.stern.nyu.edu/~wgreene/Text/tables/Tbl15_1.htm
##   firms:   see below
##   errors:  see below
##   remarks: physically identical to Greene (2003)
## - Baltagi (2002)
##   source:  http://www.springer.com/cda/content/document/cda_downloaddocument/grunfeld.dat.txt?SGWID=0-0-45-108560-0
##   firms:   10 (except American Steel)
##   errors:  none
## - Baltagi (2005)
##   source:  http://www.wiley.com/legacy/wileychi/baltagi/supp/Grunfeld.fil
##   firms:   10 (except American Steel)
##   errors:  none
## - Greene (2003)
##   source:  http://pages.stern.nyu.edu/~wgreene/Text/tables/TableF13-1.txt
##   firms:   5 (General Motors, US Steel, General Electric, Chrysler, Westinghouse)
##   errors:  invest_1940 = 261.6 (US Steel)
##            invest_1952 = 645.2 (US Steel)
##            capital_1946 = 232.6 (US Steel)
## - Greene (2008)
##   source:  http://www.stern.nyu.edu/~wgreene/Text/Edition6/Grunfeld.txt
##   firms:   10 (except American Steel)
##   errors:  none
##   remarks: physically identical to Baltagi (2005) but with mal-formatted header line
## - Hill, Griffiths, Lim (2008)
##   source:  http://www.principlesofeconometrics.com/dat/grunfeld.dat
##   firms:   10 (except American Steel)
##   errors:  invest_1953 = 81.90 (Atlantic Refining)
##            invest_1952 = 645.2 (US Steel)
##            capital_1946 = 232.6 (US Steel)

## names of firms and variables
firms <- c("General Motors", "US Steel", "General Electric", "Chrysler",
  "Atlantic Refining", "IBM", "Union Oil", "Westinghouse", "Goodyear",
  "Diamond Match", "American Steel")
vars <- c("invest", "value", "capital", "firm", "year")

## Obtain online version? (or use local copy instead)
online <- FALSE


## all 11 firms
Grunfeld11 <- read.csv("Grunfeld.csv", header = TRUE)
Grunfeld11$firm <- factor(Grunfeld11$firm, levels = firms)
## 10 firms (without American Steel)
Grunfeld10 <- subset(Grunfeld11, firm %in% firms[1:10])
## 5 firms (General Motors, US Steel, General Electric, Chrysler, Westinghouse)
Grunfeld5 <- subset(Grunfeld11, firm %in% firms[c(1:4, 8)])


## Baltagi (2002)
Baltagi1 <- read.table(paste(ifelse(online,
  "http://www.springer.com/cda/content/document/cda_downloaddocument/", ""), 
  "grunfeld.dat.txt", ifelse(online, "?SGWID=0-0-45-108560-0", ""), sep = ""), header = TRUE)
## re-arrange variables
Baltagi1 <- Baltagi1[, c(3:5, 1:2)]
names(Baltagi1) <- vars
Baltagi1$firm <- factor(Baltagi1$firm, levels = 1:11, labels = firms)
## check: ok
identical(Baltagi1, Grunfeld10)


## Baltagi (2005)
Baltagi2 <- read.table(paste(ifelse(online, 
  "http://www.wiley.com/legacy/wileychi/baltagi/supp/", ""),
  "Grunfeld.fil", sep = ""), header = FALSE)
## re-arrange variables
Baltagi2 <- Baltagi2[, c(3:5, 1:2)]
names(Baltagi2) <- vars
Baltagi2$firm <- factor(Baltagi2$firm, levels = 1:11, labels = firms)
## check: ok
identical(Baltagi2, Grunfeld10)


## Table F13.3 of Greene (2003)
Greene <- read.table(paste(ifelse(online, 
  "http://pages.stern.nyu.edu/~wgreene/Text/tables/", ""),
  "TableF13-1.txt", sep = ""), header = TRUE)
## re-arrange firms/variables
Greene <- Greene[c(1:20, 81:100, 41:60, 21:40, 61:80), c(3:5, 2:1)]
names(Greene) <- vars
row.names(Greene) <- c(1:80, 141:160)
Greene$firm <- rep(c(1, 2, 3, 4, 8), rep(20, 5))
Greene$firm <- factor(Greene$firm, levels = 1:11, labels = firms)
## check: fails
identical(Greene, Grunfeld5)
## errors in Greene (2003)
Greene$invest[c(26, 38)] <- c(361.6, 645.5)
Greene$capital[32] <- 132.6
## check again: ok
identical(Greene, Grunfeld5)


## Greene (2008)
Greene2 <- read.table(paste(ifelse(online, 
  "http://www.stern.nyu.edu/~wgreene/Text/Edition6/", ""),
  "Grunfeld.txt", sep = ""), header = FALSE, skip = 1)
## re-arrange variables
Greene2 <- Greene2[, c(3:5, 1:2)]
names(Greene2) <- vars
Greene2$firm <- factor(Greene2$firm, levels = 1:11, labels = firms)
## check: ok
identical(Greene2, Grunfeld10)


## Hill, Griffiths, Lim (2008)
HGL <- read.table(paste(ifelse(online, 
  "http://www.principlesofeconometrics.com/dat/", ""),
  "grunfeld.dat", sep = ""))
## re-arrange firms/variables
HGL <- HGL[, c(3:5, 1:2)]
names(HGL) <- vars
HGL$firm <- factor(HGL$firm, levels = 1:11, labels = firms)
HGL$year <- as.integer(HGL$year + 1934)
## check: fails
identical(HGL, Grunfeld10)
## errors in Hill, Griffiths, Lim (2008)
HGL$invest[c(38, 99)] <- c(645.5, 91.9)
HGL$capital[32] <- 132.6
## check again: ok
identical(HGL, Grunfeld10)


## Package AER accompanying Kleiber & Zeileis (2008)
## also provides 11 firm version
data("Grunfeld", package = "AER")
## check: ok
identical(Grunfeld, Grunfeld11)
